==> haskell-tasty-smallcheck-0.8.2-837.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-3Z2KXjReSNHB9wtecSUK7g
key:                  tasty-smallcheck-0.8.2-3Z2KXjReSNHB9wtecSUK7g
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  5f041f6dfb49120a8da4b7f3bc6fa521
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-3Z2KXjReSNHB9wtecSUK7g
depends:
    base-4.18.2.1 optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    smallcheck-1.2.1.1-KFqvf5MX9q0F5fKZs5XDfG
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.2-843-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-FcUOvCJlD66AbMNW4olrbE
key:                  tasty-smallcheck-0.8.2-FcUOvCJlD66AbMNW4olrbE
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  46e6815c34ff4c0ed24a56602e6a7ce2
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-FcUOvCJlD66AbMNW4olrbE
depends:
    base-4.18.2.1 optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    smallcheck-1.2.1.1-1IgojUhwjusBuCDUS7RhYP
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
